function [thetam] = dfu_wv(evalKey, parm, L, xm,ym, u,ux,uy, ...
   ps,psx,psy, pr,prx,pry);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% FEMBIF = < Finite Element Methods for Bifurcation >
%% Copyright (C) 1997  Michael Holst
%%
%% This program is free software; you can redistribute it and/or modify it
%% under the terms of the GNU General Public License as published by the Free
%% Software Foundation; either version 2 of the License, or (at your option)
%% any later version.
%%
%% This program is distributed in the hope that it will be useful, but WITHOUT
%% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
%% FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
%% more details.
%%
%% You should have received a copy of the GNU General Public License along
%% with this program; if not, write to the Free Software Foundation, Inc.,
%% 675 Mass Ave, Cambridge, MA 02139, USA.
%%
%% Typing "help 0license" should list the GNU GPL to the screen.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Prototype:
%
%     [thetam] = dfu_wv(evalKey, parm, L, xm,ym, u,ux,uy, ...
%        ps,psx,psy, pr,prx,pry);
%
% Purpose:
%
%     Evaluate the bilinear form by providing the value of the quantity
%     under the integral sign, at a particular quadrature point.
%
%     Because we do this for all of the elements at one time to make things
%     reasonably fast, we pass some arrays around.
%
% Input:
%
%     evalKey    ==> area or surface integral
%     L          ==> number of elements to do all at once
%     xm(1:L,1)  ==> x-coordindinates of quadrature points, one per element
%     ym(1:L,1)  ==> y-coordindinates of quadrature points, one per element
%     u(1:L,1)   ==> u, evaluated on master element
%     ux(1:L,1)  ==> partial w.r.t. x of u, one per element
%     uy(1:L,1)  ==> partial w.r.t. x of u, one per element
%     ps         ==> phi(s), evaluated on master element
%     psx(1:L,1) ==> partial w.r.t. x of phi(s), one per element
%     psy(1:L,1) ==> partial w.r.t. x of phi(s), one per element
%     pr         ==> phi(r), evaluated on master element
%     prx(1:L,1) ==> partial w.r.t. x of phi(r), one per element
%     pry(1:L,1) ==> partial w.r.t. x of phi(r), one per element
%
% Output:
%
%     thetam     ==> the integrand for the area or surface integral,
%                    not including the jacobian of transformation
%
% Author:   Michael Holst 050497
%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% doit
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

   lambda = parm(1);

   %%% area integral
   if (evalKey == 0)

      %%% coefficients
      atilde = ones(L,1);   % the first order coefficient function

      %%% linearized operator evaluated at the FEM function "u"
      thetam(1:L,1) = ...
          atilde(1:L,1) .* (psx(1:L,1).*prx(1:L,1)+psy(1:L,1).*pry(1:L,1)) ...
        + lambda * exp(u(1:L,1)) * ps * pr;

   %%% edge integral (for natural boundary condition)
   else if (evalKey == 1)
      thetam(1:L,1) = zeros(L,1);

   %%% error
   else
      fprintf('dfu_wv: problem!\n');
   end

end

