%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% FEMBIF = < Finite Element Methods for Bifurcation >
%% Copyright (C) 1997  Michael Holst
%%
%% This program is free software; you can redistribute it and/or modify it
%% under the terms of the GNU General Public License as published by the Free
%% Software Foundation; either version 2 of the License, or (at your option)
%% any later version.
%%
%% This program is distributed in the hope that it will be useful, but WITHOUT
%% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
%% FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
%% more details.
%%
%% You should have received a copy of the GNU General Public License along
%% with this program; if not, write to the Free Software Foundation, Inc.,
%% 675 Mass Ave, Cambridge, MA 02139, USA.
%%
%% Typing "help 0license" should list the GNU GPL to the screen.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Prototype:
%
%    None (script)
%
% Purpose:
%
%    Driver script for FEMBIF package.
%
% Author:   Michael Holst 050497
%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% doit
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%% some i/o

   clc; clf; 
   fprintf('\n');
   fprintf('-------------------------------------------------------------\n');
   fprintf('FEMBIF version 1.0, Copyright (C) 1997 Michael Holst\n');
   fprintf('This is free software, and you are welcome to redistribute it\n');
   fprintf('under certain conditions; type "help 0license" for details.\n');
   fprintf('Note that FEMBIF comes with ABSOLUTELY NO WARRANTY.\n');
   fprintf('\n');
   fprintf('For FEMBIF documentation:  In MATLAB, type "help filename".\n');
   fprintf('-------------------------------------------------------------\n');
   fprintf('\n');

   fprintf('MAIN: STARTING: Finite Element Bifurcation Code\n');

%%% controlling parameters

   levels      = 9;  %%% num of refinements plus one
   iplotMesh   = 1;  %%% plot of mesh (0=none,1=mesh)
   igraphA     = 1;  %%% graph of matrix (0=none,1=graph)
   ispyA       = 1;  %%% spy of matrix (0=none,1=spy)
   iplotSol    = 1;  %%% plot of solution (0=none,1=soln)
   igenPS      = 0;  %%% generate postscript (0=no,1=yes)

%%% construct operators for the nested sequence of spaces

   for level = 1 : levels
      fprintf('MAIN: -------\n');
      fprintf('MAIN: LEVEL %g\n',level);
      fprintf('MAIN: -------\n');

      if (level == 1)
         %%% create the initial coarse mesh
         fprintf('MAIN: defining mesh...\n');
         [VERT,SIMP] = mesh(0);
         [N,six]  = size(VERT);
         [L,nine] = size(SIMP);
         fprintf('MAIN: initial mesh with: [ N=%g, L=%g ]\n', N, L);
      else
         %%% error estimate and mark this previous mesh
         SIMP_C = SIMP;
         [SIMP] = mark(SIMP_C);
         %%% refine this previous mesh
         VERT_C = VERT;
         SIMP_C = SIMP;
         [N,six]  = size(VERT);
         [L,nine] = size(SIMP);
         fprintf('MAIN: starting with: [ N=%g, L=%g ]\n', N, L);
         fprintf('MAIN: refining the mesh...'); t0 = clock;
         [VERT,SIMP] = refin(VERT_C,SIMP_C);
         [N,six]  = size(VERT);
         [L,nine] = size(SIMP);
         the_time = etime(clock,t0); fprintf('complete: time = %g\n',the_time)  
         fprintf('MAIN: finished with: [ N=%g, L=%g ]\n', N, L);
      end;

      %%% plot the mesh
      if (iplotMesh > 0)
         fprintf('MAIN: plotting mesh [N=%g,L=%g]...\n',N,L);
         draw(VERT,SIMP);
         if (igenPS > 0)
            print -dps mesh.ps
         end
         mypaus;
      end;

      %%% solve discrete system
      fprintf('MAIN: start: nonlinear system solve [N=%g,L=%g]...\n',N,L);
      t0 = clock;
      [U,Ug,A,F]=newton(VERT,SIMP);
      the_time = etime(clock,t0);
      fprintf('MAIN: stop: nonlinear system solve; time = %g\n', the_time);

      %%% discretization error test
      U_t = zeros(N,1);
      U_t(1:N,1) = u_t(VERT(1:N,1), VERT(1:N,2));
      error = norm(U_t - (U+Ug)) / norm(U_t);
      fprintf('MAIN: discretization error is = %g\n',error); 

      %%% graph the matrix
      if (igraphA > 0)
         fprintf('MAIN: graphing matrix [N=%g,L=%g]...\n',N,L);
         gplot(A,VERT,'b');
         if (igenPS > 0)
            print -dps graph.ps
         end
         mypaus;
      end;

      %%% show matrix structure 
      if (ispyA > 0)
         fprintf('MAIN: showing nonzero structure [N=%g,L=%g]...\n',N,L);
         clf; hold off; 
         spy(A);
         if (igenPS > 0)
            print -dps spy.ps
         end
         mypaus; 
      end;

      %%% plot the solution
      if (iplotSol > 0)
         fprintf('MAIN: plotting FEM solution [N=%g,L=%g]...\n',N,L);
         drawf(VERT,SIMP,(U+Ug));
         view(30,30);
         if (igenPS > 0)
            print -dps sol.ps
         end
         mypaus; 
      end;
   end;

