function [VERT,SIMP] = mesh(n);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% FEMBIF = < Finite Element Methods for Bifurcation >
%% Copyright (C) 1997  Michael Holst
%%
%% This program is free software; you can redistribute it and/or modify it
%% under the terms of the GNU General Public License as published by the Free
%% Software Foundation; either version 2 of the License, or (at your option)
%% any later version.
%%
%% This program is distributed in the hope that it will be useful, but WITHOUT
%% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
%% FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
%% more details.
%%
%% You should have received a copy of the GNU General Public License along
%% with this program; if not, write to the Free Software Foundation, Inc.,
%% 675 Mass Ave, Cambridge, MA 02139, USA.
%%
%% Typing "help 0license" should list the GNU GPL to the screen.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Prototype:
%
%    [VERT,SIMP] = mesh(n);
%
% Purpose:
%
%    Define a 2D or 3D simplicial finite element (coordinates always in R^3).
%
%    THIS DOMAIN:  Fixed size uniform mesh on the unit square.
%
% Output:
%
%    (N = number of vertices in mesh)
%    (L = number of simplices in mesh)
%
%    VERT = size(N,6) ==> vertex coordinates
%
%              VERT(:,1) == x-coordinates of all vertices
%              VERT(:,2) == y-coordinates of all vertices
%              VERT(:,3) == z-coordinates of all vertices (3d case & manifold)
%              VERT(:,4) == integer information bitmap
%              VERT(:,5) == blank (for later use as pointer to first simplex)
%              VERT(:,6) == blank (for later use as pointer to first edge)
%
%    SIMP = size(L,9)  = simplices; vertex nums given counter-clockwise
%
%              SIMP(:,1) == 1st-vertex of all simplices
%              SIMP(:,2) == 2nd-vertex of all simplices
%              SIMP(:,3) == 3rd-vertex of all simplices
%              SIMP(:,4) == 4th-vertex of all simplices (3d case)
%              SIMP(:,5) == integer information bitmap
%              SIMP(:,6) == blank (for later use as pointer in simplex ring 1)
%              SIMP(:,7) == blank (for later use as pointer in simplex ring 2)
%              SIMP(:,8) == blank (for later use as pointer in simplex ring 3)
%              SIMP(:,9) == blank (for later use as pointer in simplex ring 4)
%
% Author:   Michael Holst 050497
%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% doit
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%% vertices array

   N = 9;
   VERT = zeros(N,6);

   VERT( 1,1:4) = [ 0.0 0.0 0.0     1 ];
   VERT( 2,1:4) = [ 0.5 0.0 0.0     1 ];
   VERT( 3,1:4) = [ 1.0 0.0 0.0     1 ];
   VERT( 4,1:4) = [ 0.0 0.5 0.0     2 ];
   VERT( 5,1:4) = [ 0.5 0.5 0.0     0 ];
   VERT( 6,1:4) = [ 1.0 0.5 0.0     2 ];
   VERT( 7,1:4) = [ 0.0 1.0 0.0     1 ];
   VERT( 8,1:4) = [ 0.5 1.0 0.0     1 ];
   VERT( 9,1:4) = [ 1.0 1.0 0.0     1 ];

   VERT(:,5:6) = zeros(N,2);

%%% simplices array

   L = 8;
   SIMP = zeros(L,9);

   SIMP( 1,1:5) = [ 1  2  4  0     288 ];
   SIMP( 2,1:5) = [ 2  5  4  0       0 ];
   SIMP( 3,1:5) = [ 2  3  5  0     256 ];
   SIMP( 4,1:5) = [ 3  6  5  0     512 ];
   SIMP( 5,1:5) = [ 4  5  7  0      32 ];
   SIMP( 6,1:5) = [ 5  8  7  0       1 ];
   SIMP( 7,1:5) = [ 5  6  8  0       0 ];
   SIMP( 8,1:5) = [ 6  9  8  0     513 ];

   SIMP(:,6:9) = zeros(L,4);

